@@ -22,9 +22,10 @@ class ContextFilter(logging.Filter):
 def logging_setup() -> Tuple[logging.Logger, io.StringIO]:
 
     log = logging.getLogger("root")
+    log.setLevel(logging.DEBUG)
+
     log_stringio = io.StringIO()
     handler = logging.StreamHandler(log_stringio)
-    log.setLevel(logging.INFO)
 
     log_formatter = logging.Formatter(
         fmt="%(asctime)s | %(module)s | %(levelname)s | %(context)s | %(message)s",
@@ -33,13 +34,25 @@ def logging_setup() -> Tuple[logging.Logger, io.StringIO]:
     handler.setFormatter(log_formatter)
     log.addHandler(handler)
 
+    # Add console output
+    console = logging.StreamHandler()
+    console.setLevel(logging.INFO)
+    console.setFormatter(log_formatter)
+    log.addHandler(console)
+
     cf = ContextFilter()
     log.addFilter(cf)
 
     return log, log_stringio
 
 
-def upload_log(body: str, s3_path: str):
-    s3_client = boto3.client("s3")
-    b, k = s3_path_to_bucket_key(s3_path)
-    s3_client.put_object(Body=body, Bucket=b, Key=k)
+def upload_log(log: logging.Logger, log_stringio: io.StringIO, s3_path: str):
+    if s3_path:
+        s3_client = boto3.client("s3")
+        b, k = s3_path_to_bucket_key(s3_path)
+        s3_client.put_object(Body=log_stringio.getvalue(), Bucket=b, Key=k)
+    else:
+        log.error(
+            "An error occurred but no log path registered, "
+            "likely due to issue with config, so cannot upload to log S3."
+        )
