@@ -4,6 +4,7 @@ import boto3
 import gzip
 import tempfile
 
+from typing import Union
 from pathlib import Path
 
 from dataengineeringutils3.s3 import (
@@ -11,9 +12,6 @@ from dataengineeringutils3.s3 import (
     write_local_file_to_s3,
 )
 
-# import logging
-# log = logging.getLogger("root")
-
 
 def download_data(s3_path: str, local_path: str):
     s3_client = boto3.client("s3")
@@ -43,20 +41,24 @@ def get_out_path(
     filename: str,
     compress: bool = False,
     filenum: int = 0,
+    timestamp_partition_name: Union[str, None] = None,
 ) -> str:
     filename_only, ext = filename.split(".", 1)
-    final_filename = f"{filename_only}-{ts}-{filenum}.{ext}"
+    final_filename = f"{filename_only}-{filenum}-{ts}.{ext}"
     if compress and not ext.endswith(".gz"):
         final_filename += ".gz"
 
-    out_path = os.path.join(
-        basepath, table, f"mojap_file_land_timestamp={ts}", final_filename
-    )
+    if timestamp_partition_name:
+        out_path = os.path.join(
+            basepath, table, f"{timestamp_partition_name}={ts}", final_filename
+        )
+    else:
+        out_path = os.path.join(basepath, table, final_filename)
     return out_path
 
 
 def get_log_path(basepath: str, table: str, ts: str, filenum: int = 0) -> str:
-    final_filename = f"log-{table}-{ts}-{filenum}.json"
+    final_filename = f"log-{table}-{filenum}-{ts}.json"
 
     out_path = os.path.join(basepath, table, final_filename)
     return out_path
